# ELIT Morphological Analyzer

[ELIT](https://github.com/emorynlp/elit/) (Emory Information and Language Technology) features an English morphological analyzer that provides a comprehensive mophological analysis using inflection and derivation rules. 
This project is led by the [Emory NLP Research Laboratory](https://www.emorynlp.org) and under the [Apache 2.0](LICENSE) license.

* Latest release: [1.0](https://pypi.org/project/elit_morph_analyzer/) (05/19/2022)

## Installation

Python 3.7 or higher is recommended: 

```
pip install elit_morph_analyzer
```

## Documentation

* [English Morphological Analyzer](https://github.com/emorynlp/elit-morph_analyzer/blob/master/docs/EnglishMorphAnalyzer.md)

## Contact

* [Jinho D. Choi](http://www.cs.emory.edu/~choi)
